"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "type"


async def deprecate(hub, ctx, domain: str, workflow_type: Dict) -> None:
    r"""
    **Autogenerated function**

    Deprecates the specified workflow type. After a workflow type has been deprecated, you cannot create new executions of that type. Executions that were started before the type was deprecated continues to run. A deprecated workflow type may still be used when calling visibility actions.  This operation is eventually consistent. The results are best effort and may not exactly reflect recent updates and changes.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   Constrain the following parameters by using a Condition element with the appropriate keys.    workflowType.name: String constraint. The key is swf:workflowType.name.    workflowType.version: String constraint. The key is swf:workflowType.version.     If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain in which the workflow type is registered.
        workflow_type(Dict): The workflow type to deprecate.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.workflow.type_.deprecate(
                ctx, domain=value, workflow_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.workflow.type.deprecate domain=value, workflow_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="deprecate_workflow_type",
        op_kwargs={"domain": domain, "workflowType": workflow_type},
    )


async def describe(hub, ctx, domain: str, workflow_type: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified workflow type. This includes configuration settings specified when the type was registered and other information such as creation date, current status, etc.  Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   Constrain the following parameters by using a Condition element with the appropriate keys.    workflowType.name: String constraint. The key is swf:workflowType.name.    workflowType.version: String constraint. The key is swf:workflowType.version.     If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain in which this workflow type is registered.
        workflow_type(Dict): The workflow type to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.workflow.type_.describe(
                ctx, domain=value, workflow_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.workflow.type.describe domain=value, workflow_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="describe_workflow_type",
        op_kwargs={"domain": domain, "workflowType": workflow_type},
    )


async def list_all(
    hub,
    ctx,
    domain: str,
    registration_status: str,
    name: str = None,
    next_page_token: str = None,
    maximum_page_size: int = None,
    reverse_order: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about workflow types in the specified domain. The results may be split into multiple pages that can be retrieved by making the call repeatedly.  Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain in which the workflow types have been registered.
        name(str, optional): If specified, lists the workflow type with this name. Defaults to None.
        registration_status(str): Specifies the registration status of the workflow types to list.
        next_page_token(str, optional): If NextPageToken is returned there are more results available. The value of NextPageToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 60 seconds. Using an expired pagination token will return a 400 error: "Specified token has exceeded its maximum lifetime".  The configured maximumPageSize determines how many results can be returned in a single call. . Defaults to None.
        maximum_page_size(int, optional): The maximum number of results that are returned per call. Use nextPageToken to obtain further pages of results. . Defaults to None.
        reverse_order(bool, optional): When set to true, returns the results in reverse order. By default the results are returned in ascending alphabetical order of the name of the workflow types. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.workflow.type_.list_all(
                ctx, domain=value, registration_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.workflow.type.list_all domain=value, registration_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="list_workflow_types",
        op_kwargs={
            "domain": domain,
            "name": name,
            "registrationStatus": registration_status,
            "nextPageToken": next_page_token,
            "maximumPageSize": maximum_page_size,
            "reverseOrder": reverse_order,
        },
    )


async def register(
    hub,
    ctx,
    domain: str,
    name: str,
    version: str,
    description: str = None,
    default_task_start_to_close_timeout: str = None,
    default_execution_start_to_close_timeout: str = None,
    default_task_list: Dict = None,
    default_task_priority: str = None,
    default_child_policy: str = None,
    default_lambda_role: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Registers a new workflow type and its configuration settings in the specified domain. The retention period for the workflow history is set by the RegisterDomain action.  If the type already exists, then a TypeAlreadyExists fault is returned. You cannot change the configuration settings of a workflow type once it is registered and it must be registered as a new version.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   Constrain the following parameters by using a Condition element with the appropriate keys.    defaultTaskList.name: String constraint. The key is swf:defaultTaskList.name.    name: String constraint. The key is swf:name.    version: String constraint. The key is swf:version.     If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain in which to register the workflow type.
        name(str): The name of the workflow type. The specified string must not start or end with whitespace. It must not contain a : (colon), / (slash), | (vertical bar), or any control characters (\u0000-\u001f | \u007f-\u009f). Also, it must not be the literal string arn.
        version(str): The version of the workflow type.  The workflow type consists of the name and version, the combination of which must be unique within the domain. To get a list of all currently registered workflow types, use the ListWorkflowTypes action.  The specified string must not start or end with whitespace. It must not contain a : (colon), / (slash), | (vertical bar), or any control characters (\u0000-\u001f | \u007f-\u009f). Also, it must not be the literal string arn.
        description(str, optional): Textual description of the workflow type. Defaults to None.
        default_task_start_to_close_timeout(str, optional): If set, specifies the default maximum duration of decision tasks for this workflow type. This default can be overridden when starting a workflow execution using the StartWorkflowExecution action or the StartChildWorkflowExecution Decision. The duration is specified in seconds, an integer greater than or equal to 0. You can use NONE to specify unlimited duration. Defaults to None.
        default_execution_start_to_close_timeout(str, optional): If set, specifies the default maximum duration for executions of this workflow type. You can override this default when starting an execution through the StartWorkflowExecution Action or StartChildWorkflowExecution Decision. The duration is specified in seconds; an integer greater than or equal to 0. Unlike some of the other timeout parameters in Amazon SWF, you cannot specify a value of "NONE" for defaultExecutionStartToCloseTimeout; there is a one-year max limit on the time that a workflow execution can run. Exceeding this limit always causes the workflow execution to time out. Defaults to None.
        default_task_list(Dict, optional): If set, specifies the default task list to use for scheduling decision tasks for executions of this workflow type. This default is used only if a task list isn't provided when starting the execution through the StartWorkflowExecution Action or StartChildWorkflowExecution Decision. Defaults to None.
        default_task_priority(str, optional): The default task priority to assign to the workflow type. If not assigned, then 0 is used. Valid values are integers that range from Java's Integer.MIN_VALUE (-2147483648) to Integer.MAX_VALUE (2147483647). Higher numbers indicate higher priority. For more information about setting task priority, see Setting Task Priority in the Amazon SWF Developer Guide. Defaults to None.
        default_child_policy(str, optional): If set, specifies the default policy to use for the child workflow executions when a workflow execution of this type is terminated, by calling the TerminateWorkflowExecution action explicitly or due to an expired timeout. This default can be overridden when starting a workflow execution using the StartWorkflowExecution action or the StartChildWorkflowExecution Decision. The supported child policies are:    TERMINATE – The child executions are terminated.    REQUEST_CANCEL – A request to cancel is attempted for each child execution by recording a WorkflowExecutionCancelRequested event in its history. It is up to the decider to take appropriate actions when it receives an execution history with this event.    ABANDON – No action is taken. The child executions continue to run.  . Defaults to None.
        default_lambda_role(str, optional): The default IAM role attached to this workflow type.  Executions of this workflow type need IAM roles to invoke Lambda functions. If you don't specify an IAM role when you start this workflow type, the default Lambda role is attached to the execution. For more information, see https://docs.aws.amazon.com/amazonswf/latest/developerguide/lambda-task.html in the Amazon SWF Developer Guide. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.workflow.type_.register(
                ctx, domain=value, name=value, version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.workflow.type.register domain=value, name=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="register_workflow_type",
        op_kwargs={
            "domain": domain,
            "name": name,
            "version": version,
            "description": description,
            "defaultTaskStartToCloseTimeout": default_task_start_to_close_timeout,
            "defaultExecutionStartToCloseTimeout": default_execution_start_to_close_timeout,
            "defaultTaskList": default_task_list,
            "defaultTaskPriority": default_task_priority,
            "defaultChildPolicy": default_child_policy,
            "defaultLambdaRole": default_lambda_role,
        },
    )


async def undeprecate(hub, ctx, domain: str, workflow_type: Dict) -> None:
    r"""
    **Autogenerated function**

    Undeprecates a previously deprecated workflow type. After a workflow type has been undeprecated, you can create new executions of that type.   This operation is eventually consistent. The results are best effort and may not exactly reflect recent updates and changes.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   Constrain the following parameters by using a Condition element with the appropriate keys.    workflowType.name: String constraint. The key is swf:workflowType.name.    workflowType.version: String constraint. The key is swf:workflowType.version.     If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain of the deprecated workflow type.
        workflow_type(Dict): The name of the domain of the deprecated workflow type.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.workflow.type_.undeprecate(
                ctx, domain=value, workflow_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.workflow.type.undeprecate domain=value, workflow_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="undeprecate_workflow_type",
        op_kwargs={"domain": domain, "workflowType": workflow_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    bucket: str,
    key: str,
    version_id: str = None,
    request_payer: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the access control list (ACL) of an object. To use this operation, you must have READ_ACP access to the object. This action is not supported by Amazon S3 on Outposts.  Versioning  By default, GET returns ACL information about the current version of an object. To return ACL information about a different version, use the versionId subresource. The following operations are related to GetObjectAcl:    GetObject     DeleteObject     PutObject

    Args:
        bucket(str): The bucket name that contains the object for which to get the ACL information.  When using this action with an access point, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the AWS SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.
        key(str): The key of the object for which to get the ACL information.
        version_id(str, optional): VersionId used to reference a specific version of the object. Defaults to None.
        request_payer(str, optional): Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. For information about downloading objects from requester pays buckets, see Downloading Objects in Requestor Pays Buckets in the Amazon S3 User Guide. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.object_.acl.get(ctx, bucket=value, key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.object_.acl.get bucket=value, key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_object_acl",
        op_kwargs={
            "Bucket": bucket,
            "Key": key,
            "VersionId": version_id,
            "RequestPayer": request_payer,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def put(
    hub,
    ctx,
    bucket: str,
    key: str,
    acl: str = None,
    access_control_policy: Dict = None,
    content_md5: str = None,
    grant_full_control: str = None,
    grant_read: str = None,
    grant_read_acp: str = None,
    grant_write: str = None,
    grant_write_acp: str = None,
    request_payer: str = None,
    version_id: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Uses the acl subresource to set the access control list (ACL) permissions for a new or existing object in an S3 bucket. You must have WRITE_ACP permission to set the ACL of an object. For more information, see What permissions can I grant? in the Amazon S3 User Guide. This action is not supported by Amazon S3 on Outposts. Depending on your application needs, you can choose to set the ACL on an object using either the request body or the headers. For example, if you have an existing application that updates a bucket ACL using the request body, you can continue to use that approach. For more information, see Access Control List (ACL) Overview in the Amazon S3 User Guide.  Access Permissions  You can set access permissions using one of the following methods:   Specify a canned ACL with the x-amz-acl request header. Amazon S3 supports a set of predefined ACLs, known as canned ACLs. Each canned ACL has a predefined set of grantees and permissions. Specify the canned ACL name as the value of x-amz-acl. If you use this header, you cannot use other access control-specific headers in your request. For more information, see Canned ACL.   Specify access permissions explicitly with the x-amz-grant-read, x-amz-grant-read-acp, x-amz-grant-write-acp, and x-amz-grant-full-control headers. When using these headers, you specify explicit access permissions and grantees (AWS accounts or Amazon S3 groups) who will receive the permission. If you use these ACL-specific headers, you cannot use x-amz-acl header to set a canned ACL. These parameters map to the set of permissions that Amazon S3 supports in an ACL. For more information, see Access Control List (ACL) Overview. You specify each grantee as a type=value pair, where the type is one of the following:    id – if the value specified is the canonical user ID of an AWS account    uri – if you are granting permissions to a predefined group    emailAddress – if the value specified is the email address of an AWS account  Using email addresses to specify a grantee is only supported in the following AWS Regions:    US East (N. Virginia)   US West (N. California)    US West (Oregon)    Asia Pacific (Singapore)   Asia Pacific (Sydney)   Asia Pacific (Tokyo)   Europe (Ireland)   South America (São Paulo)   For a list of all the Amazon S3 supported Regions and endpoints, see Regions and Endpoints in the AWS General Reference.    For example, the following x-amz-grant-read header grants list objects permission to the two AWS accounts identified by their email addresses.  x-amz-grant-read: emailAddress="xyz@amazon.com", emailAddress="abc@amazon.com"     You can use either a canned ACL or specify access permissions explicitly. You cannot do both.  Grantee Values  You can specify the person (grantee) to whom you're assigning access rights (using request elements) in the following ways:   By the person's ID:  <Grantee xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:type="CanonicalUser"><ID><>ID<></ID><DisplayName><>GranteesEmail<></DisplayName> </Grantee>  DisplayName is optional and ignored in the request.   By URI:  <Grantee xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:type="Group"><URI><>http://acs.amazonaws.com/groups/global/AuthenticatedUsers<></URI></Grantee>    By Email address:  <Grantee xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:type="AmazonCustomerByEmail"><EmailAddress><>Grantees@email.com<></EmailAddress>lt;/Grantee>  The grantee is resolved to the CanonicalUser and, in a response to a GET Object acl request, appears as the CanonicalUser.  Using email addresses to specify a grantee is only supported in the following AWS Regions:    US East (N. Virginia)   US West (N. California)    US West (Oregon)    Asia Pacific (Singapore)   Asia Pacific (Sydney)   Asia Pacific (Tokyo)   Europe (Ireland)   South America (São Paulo)   For a list of all the Amazon S3 supported Regions and endpoints, see Regions and Endpoints in the AWS General Reference.     Versioning  The ACL of an object is set at the object version level. By default, PUT sets the ACL of the current version of an object. To set the ACL of a different version, use the versionId subresource.  Related Resources     CopyObject     GetObject

    Args:
        acl(str, optional): The canned ACL to apply to the object. For more information, see Canned ACL. Defaults to None.
        access_control_policy(Dict, optional): Contains the elements that set the ACL permissions for an object per grantee. Defaults to None.
        bucket(str): The bucket name that contains the object to which you want to attach the ACL.  When using this action with an access point, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the AWS SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.
        content_md5(str, optional): The base64-encoded 128-bit MD5 digest of the data. This header must be used as a message integrity check to verify that the request body was not corrupted in transit. For more information, go to RFC 1864.>  For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        grant_full_control(str, optional): Allows grantee the read, write, read ACP, and write ACP permissions on the bucket. This action is not supported by Amazon S3 on Outposts. Defaults to None.
        grant_read(str, optional): Allows grantee to list the objects in the bucket. This action is not supported by Amazon S3 on Outposts. Defaults to None.
        grant_read_acp(str, optional): Allows grantee to read the bucket ACL. This action is not supported by Amazon S3 on Outposts. Defaults to None.
        grant_write(str, optional): Allows grantee to create new objects in the bucket. For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects. Defaults to None.
        grant_write_acp(str, optional): Allows grantee to write the ACL for the applicable bucket. This action is not supported by Amazon S3 on Outposts. Defaults to None.
        key(str): Key for which the PUT action was initiated. When using this action with an access point, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the AWS SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. When using this action with Amazon S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com. When using this action using S3 on Outposts through the AWS SDKs, you provide the Outposts bucket ARN in place of the bucket name. For more information about S3 on Outposts ARNs, see Using S3 on Outposts in the Amazon S3 User Guide.
        request_payer(str, optional): Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. For information about downloading objects from requester pays buckets, see Downloading Objects in Requestor Pays Buckets in the Amazon S3 User Guide. Defaults to None.
        version_id(str, optional): VersionId used to reference a specific version of the object. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.object_.acl.put(ctx, bucket=value, key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.object_.acl.put bucket=value, key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_object_acl",
        op_kwargs={
            "ACL": acl,
            "AccessControlPolicy": access_control_policy,
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "GrantFullControl": grant_full_control,
            "GrantRead": grant_read,
            "GrantReadACP": grant_read_acp,
            "GrantWrite": grant_write,
            "GrantWriteACP": grant_write_acp,
            "Key": key,
            "RequestPayer": request_payer,
            "VersionId": version_id,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    dag_s3_path: str,
    execution_role_arn: str,
    name: str,
    network_configuration: Dict,
    source_bucket_arn: str,
    airflow_configuration_options: Dict = None,
    airflow_version: str = None,
    environment_class: str = None,
    kms_key: str = None,
    logging_configuration: Dict = None,
    max_workers: int = None,
    min_workers: int = None,
    plugins_s3_object_version: str = None,
    plugins_s3_path: str = None,
    requirements_s3_object_version: str = None,
    requirements_s3_path: str = None,
    schedulers: int = None,
    tags: Dict = None,
    webserver_access_mode: str = None,
    weekly_maintenance_window_start: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Managed Workflows for Apache Airflow (MWAA) environment.

    Args:
        airflow_configuration_options(Dict, optional): A list of key-value pairs containing the Apache Airflow configuration options you want to attach to your environment. To learn more, see Apache Airflow configuration options. Defaults to None.
        airflow_version(str, optional): The Apache Airflow version for your environment. For example, v1.10.12. If no value is specified, defaults to the latest version. Valid values: v1.10.12. Defaults to None.
        dag_s3_path(str): The relative path to the DAGs folder on your Amazon S3 bucket. For example, dags. To learn more, see Adding or updating DAGs.
        environment_class(str, optional): The environment class type. Valid values: mw1.small, mw1.medium, mw1.large. To learn more, see Amazon MWAA environment class. Defaults to None.
        execution_role_arn(str): The Amazon Resource Name (ARN) of the execution role for your environment. An execution role is an AWS Identity and Access Management (IAM) role that grants MWAA permission to access AWS services and resources used by your environment. For example, arn:aws:iam::123456789:role/my-execution-role. To learn more, see Amazon MWAA Execution role.
        kms_key(str, optional): The AWS Key Management Service (KMS) key to encrypt the data in your environment. You can use an AWS owned CMK, or a Customer managed CMK (advanced). To learn more, see Get started with Amazon Managed Workflows for Apache Airflow. Defaults to None.
        logging_configuration(Dict, optional): Defines the Apache Airflow logs to send to CloudWatch Logs: DagProcessingLogs, SchedulerLogs, TaskLogs, WebserverLogs, WorkerLogs. Defaults to None.
        max_workers(int, optional): The maximum number of workers that you want to run in your environment. MWAA scales the number of Apache Airflow workers up to the number you specify in the MaxWorkers field. For example, 20. When there are no more tasks running, and no more in the queue, MWAA disposes of the extra workers leaving the one worker that is included with your environment, or the number you specify in MinWorkers. Defaults to None.
        min_workers(int, optional): The minimum number of workers that you want to run in your environment. MWAA scales the number of Apache Airflow workers up to the number you specify in the MaxWorkers field. When there are no more tasks running, and no more in the queue, MWAA disposes of the extra workers leaving the worker count you specify in the MinWorkers field. For example, 2. Defaults to None.
        name(str): The name of the Amazon MWAA environment. For example, MyMWAAEnvironment.
        network_configuration(Dict): The VPC networking components used to secure and enable network traffic between the AWS resources for your environment. To learn more, see About networking on Amazon MWAA.
        plugins_s3_object_version(str, optional): The version of the plugins.zip file on your Amazon S3 bucket. A version must be specified each time a plugins.zip file is updated. To learn more, see How S3 Versioning works. Defaults to None.
        plugins_s3_path(str, optional): The relative path to the plugins.zip file on your Amazon S3 bucket. For example, plugins.zip. If specified, then the plugins.zip version is required. To learn more, see Installing custom plugins. Defaults to None.
        requirements_s3_object_version(str, optional): The version of the requirements.txt file on your Amazon S3 bucket. A version must be specified each time a requirements.txt file is updated. To learn more, see How S3 Versioning works. Defaults to None.
        requirements_s3_path(str, optional): The relative path to the requirements.txt file on your Amazon S3 bucket. For example, requirements.txt. If specified, then a file version is required. To learn more, see Installing Python dependencies. Defaults to None.
        schedulers(int, optional): The number of Apache Airflow schedulers to run in your environment. Defaults to None.
        source_bucket_arn(str): The Amazon Resource Name (ARN) of the Amazon S3 bucket where your DAG code and supporting files are stored. For example, arn:aws:s3:::my-airflow-bucket-unique-name. To learn more, see Create an Amazon S3 bucket for Amazon MWAA.
        tags(Dict, optional): The key-value tag pairs you want to associate to your environment. For example, "Environment": "Staging". To learn more, see Tagging AWS resources. Defaults to None.
        webserver_access_mode(str, optional): The Apache Airflow Web server access mode. To learn more, see Apache Airflow access modes. Defaults to None.
        weekly_maintenance_window_start(str, optional): The day and time of the week to start weekly maintenance updates of your environment in the following format: DAY:HH:MM. For example: TUE:03:30. You can specify a start time in 30 minute increments only. Supported input includes the following:   MON|TUE|WED|THU|FRI|SAT|SUN:([01]\\d|2[0-3]):(00|30)  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mwaa.environment.create(
                ctx,
                dag_s3_path=value,
                execution_role_arn=value,
                name=value,
                network_configuration=value,
                source_bucket_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mwaa.environment.create dag_s3_path=value, execution_role_arn=value, name=value, network_configuration=value, source_bucket_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mwaa",
        operation="create_environment",
        op_kwargs={
            "AirflowConfigurationOptions": airflow_configuration_options,
            "AirflowVersion": airflow_version,
            "DagS3Path": dag_s3_path,
            "EnvironmentClass": environment_class,
            "ExecutionRoleArn": execution_role_arn,
            "KmsKey": kms_key,
            "LoggingConfiguration": logging_configuration,
            "MaxWorkers": max_workers,
            "MinWorkers": min_workers,
            "Name": name,
            "NetworkConfiguration": network_configuration,
            "PluginsS3ObjectVersion": plugins_s3_object_version,
            "PluginsS3Path": plugins_s3_path,
            "RequirementsS3ObjectVersion": requirements_s3_object_version,
            "RequirementsS3Path": requirements_s3_path,
            "Schedulers": schedulers,
            "SourceBucketArn": source_bucket_arn,
            "Tags": tags,
            "WebserverAccessMode": webserver_access_mode,
            "WeeklyMaintenanceWindowStart": weekly_maintenance_window_start,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Amazon Managed Workflows for Apache Airflow (MWAA) environment.

    Args:
        name(str): The name of the Amazon MWAA environment. For example, MyMWAAEnvironment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mwaa.environment.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mwaa.environment.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mwaa",
        operation="delete_environment",
        op_kwargs={"Name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the details of an Amazon Managed Workflows for Apache Airflow (MWAA) environment.

    Args:
        name(str): The name of the Amazon MWAA environment. For example, MyMWAAEnvironment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mwaa.environment.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mwaa.environment.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="mwaa", operation="get_environment", op_kwargs={"Name": name}
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Amazon Managed Workflows for Apache Airflow (MWAA) environments.

    Args:
        max_results(int, optional): The maximum number of results to retrieve per page. For example, 5 environments per page. Defaults to None.
        next_token(str, optional): Retrieves the next page of the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mwaa.environment.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mwaa.environment.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mwaa",
        operation="list_environments",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    name: str,
    airflow_configuration_options: Dict = None,
    airflow_version: str = None,
    dag_s3_path: str = None,
    environment_class: str = None,
    execution_role_arn: str = None,
    logging_configuration: Dict = None,
    max_workers: int = None,
    min_workers: int = None,
    network_configuration: Dict = None,
    plugins_s3_object_version: str = None,
    plugins_s3_path: str = None,
    requirements_s3_object_version: str = None,
    requirements_s3_path: str = None,
    schedulers: int = None,
    source_bucket_arn: str = None,
    webserver_access_mode: str = None,
    weekly_maintenance_window_start: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an Amazon Managed Workflows for Apache Airflow (MWAA) environment.

    Args:
        airflow_configuration_options(Dict, optional): A list of key-value pairs containing the Apache Airflow configuration options you want to attach to your environment. To learn more, see Apache Airflow configuration options. Defaults to None.
        airflow_version(str, optional): The Apache Airflow version for your environment. For example, v1.10.12. If no value is specified, defaults to the latest version. Valid values: v1.10.12. Defaults to None.
        dag_s3_path(str, optional): The relative path to the DAGs folder on your Amazon S3 bucket. For example, dags. To learn more, see Adding or updating DAGs. Defaults to None.
        environment_class(str, optional): The environment class type. Valid values: mw1.small, mw1.medium, mw1.large. To learn more, see Amazon MWAA environment class. Defaults to None.
        execution_role_arn(str, optional): The Amazon Resource Name (ARN) of the execution role in IAM that allows MWAA to access AWS resources in your environment. For example, arn:aws:iam::123456789:role/my-execution-role. To learn more, see Amazon MWAA Execution role. Defaults to None.
        logging_configuration(Dict, optional): Defines the Apache Airflow logs to send to CloudWatch Logs: DagProcessingLogs, SchedulerLogs, TaskLogs, WebserverLogs, WorkerLogs. Defaults to None.
        max_workers(int, optional): The maximum number of workers that you want to run in your environment. MWAA scales the number of Apache Airflow workers up to the number you specify in the MaxWorkers field. For example, 20. When there are no more tasks running, and no more in the queue, MWAA disposes of the extra workers leaving the one worker that is included with your environment, or the number you specify in MinWorkers. Defaults to None.
        min_workers(int, optional): The minimum number of workers that you want to run in your environment. MWAA scales the number of Apache Airflow workers up to the number you specify in the MaxWorkers field. When there are no more tasks running, and no more in the queue, MWAA disposes of the extra workers leaving the worker count you specify in the MinWorkers field. For example, 2. Defaults to None.
        name(str): The name of your Amazon MWAA environment. For example, MyMWAAEnvironment.
        network_configuration(Dict, optional): The VPC networking components used to secure and enable network traffic between the AWS resources for your environment. To learn more, see About networking on Amazon MWAA. Defaults to None.
        plugins_s3_object_version(str, optional): The version of the plugins.zip file on your Amazon S3 bucket. A version must be specified each time a plugins.zip file is updated. To learn more, see How S3 Versioning works. Defaults to None.
        plugins_s3_path(str, optional): The relative path to the plugins.zip file on your Amazon S3 bucket. For example, plugins.zip. If specified, then the plugins.zip version is required. To learn more, see Installing custom plugins. Defaults to None.
        requirements_s3_object_version(str, optional): The version of the requirements.txt file on your Amazon S3 bucket. A version must be specified each time a requirements.txt file is updated. To learn more, see How S3 Versioning works. Defaults to None.
        requirements_s3_path(str, optional): The relative path to the requirements.txt file on your Amazon S3 bucket. For example, requirements.txt. If specified, then a file version is required. To learn more, see Installing Python dependencies. Defaults to None.
        schedulers(int, optional): The number of Apache Airflow schedulers to run in your Amazon MWAA environment. Defaults to None.
        source_bucket_arn(str, optional): The Amazon Resource Name (ARN) of the Amazon S3 bucket where your DAG code and supporting files are stored. For example, arn:aws:s3:::my-airflow-bucket-unique-name. To learn more, see Create an Amazon S3 bucket for Amazon MWAA. Defaults to None.
        webserver_access_mode(str, optional): The Apache Airflow Web server access mode. To learn more, see Apache Airflow access modes. Defaults to None.
        weekly_maintenance_window_start(str, optional): The day and time of the week to start weekly maintenance updates of your environment in the following format: DAY:HH:MM. For example: TUE:03:30. You can specify a start time in 30 minute increments only. Supported input includes the following:   MON|TUE|WED|THU|FRI|SAT|SUN:([01]\\d|2[0-3]):(00|30)  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mwaa.environment.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mwaa.environment.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mwaa",
        operation="update_environment",
        op_kwargs={
            "AirflowConfigurationOptions": airflow_configuration_options,
            "AirflowVersion": airflow_version,
            "DagS3Path": dag_s3_path,
            "EnvironmentClass": environment_class,
            "ExecutionRoleArn": execution_role_arn,
            "LoggingConfiguration": logging_configuration,
            "MaxWorkers": max_workers,
            "MinWorkers": min_workers,
            "Name": name,
            "NetworkConfiguration": network_configuration,
            "PluginsS3ObjectVersion": plugins_s3_object_version,
            "PluginsS3Path": plugins_s3_path,
            "RequirementsS3ObjectVersion": requirements_s3_object_version,
            "RequirementsS3Path": requirements_s3_path,
            "Schedulers": schedulers,
            "SourceBucketArn": source_bucket_arn,
            "WebserverAccessMode": webserver_access_mode,
            "WeeklyMaintenanceWindowStart": weekly_maintenance_window_start,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"set_": "set"}


async def get_all(hub, ctx, queue_url: str, attribute_names: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets attributes for the specified queue.  To determine whether a queue is FIFO, you can check whether QueueName ends with the .fifo suffix.

    Args:
        queue_url(str): The URL of the Amazon SQS queue whose attribute information is retrieved. Queue URLs and names are case-sensitive.
        attribute_names(List, optional): A list of attributes for which to retrieve information. The AttributeName.N parameter is optional, but if you don't specify values for this parameter, the request returns empty results.  In the future, new attributes might be added. If you write code that calls this action, we recommend that you structure your code so that it can handle new attributes gracefully.  The following attributes are supported:  The ApproximateNumberOfMessagesDelayed, ApproximateNumberOfMessagesNotVisible, and ApproximateNumberOfMessagesVisible metrics may not achieve consistency until at least 1 minute after the producers stop sending messages. This period is required for the queue metadata to reach eventual consistency.      All – Returns all values.     ApproximateNumberOfMessages – Returns the approximate number of messages available for retrieval from the queue.    ApproximateNumberOfMessagesDelayed – Returns the approximate number of messages in the queue that are delayed and not available for reading immediately. This can happen when the queue is configured as a delay queue or when a message has been sent with a delay parameter.    ApproximateNumberOfMessagesNotVisible – Returns the approximate number of messages that are in flight. Messages are considered to be in flight if they have been sent to a client but have not yet been deleted or have not yet reached the end of their visibility window.     CreatedTimestamp – Returns the time when the queue was created in seconds (epoch time).    DelaySeconds – Returns the default delay on the queue in seconds.    LastModifiedTimestamp – Returns the time when the queue was last changed in seconds (epoch time).    MaximumMessageSize – Returns the limit of how many bytes a message can contain before Amazon SQS rejects it.    MessageRetentionPeriod – Returns the length of time, in seconds, for which Amazon SQS retains a message.    Policy – Returns the policy of the queue.    QueueArn – Returns the Amazon resource name (ARN) of the queue.    ReceiveMessageWaitTimeSeconds – Returns the length of time, in seconds, for which the ReceiveMessage action waits for a message to arrive.     RedrivePolicy – The string that includes the parameters for the dead-letter queue functionality of the source queue as a JSON object. For more information about the redrive policy and dead-letter queues, see Using Amazon SQS Dead-Letter Queues in the Amazon SQS Developer Guide.    deadLetterTargetArn – The Amazon Resource Name (ARN) of the dead-letter queue to which Amazon SQS moves messages after the value of maxReceiveCount is exceeded.    maxReceiveCount – The number of times a message is delivered to the source queue before being moved to the dead-letter queue. When the ReceiveCount for a message exceeds the maxReceiveCount for a queue, Amazon SQS moves the message to the dead-letter-queue.      VisibilityTimeout – Returns the visibility timeout for the queue. For more information about the visibility timeout, see Visibility Timeout in the Amazon SQS Developer Guide.    The following attributes apply only to server-side-encryption:    KmsMasterKeyId – Returns the ID of an Amazon Web Services managed customer master key (CMK) for Amazon SQS or a custom CMK. For more information, see Key Terms.     KmsDataKeyReusePeriodSeconds – Returns the length of time, in seconds, for which Amazon SQS can reuse a data key to encrypt or decrypt messages before calling KMS again. For more information, see How Does the Data Key Reuse Period Work?.    The following attributes apply only to FIFO (first-in-first-out) queues:    FifoQueue – Returns information about whether the queue is FIFO. For more information, see FIFO queue logic in the Amazon SQS Developer Guide.  To determine whether a queue is FIFO, you can check whether QueueName ends with the .fifo suffix.     ContentBasedDeduplication – Returns whether content-based deduplication is enabled for the queue. For more information, see Exactly-once processing in the Amazon SQS Developer Guide.    The following attributes apply only to high throughput for FIFO queues:    DeduplicationScope – Specifies whether message deduplication occurs at the message group or queue level. Valid values are messageGroup and queue.    FifoThroughputLimit – Specifies whether the FIFO queue throughput quota applies to the entire queue or per message group. Valid values are perQueue and perMessageGroupId. The perMessageGroupId value is allowed only when the value for DeduplicationScope is messageGroup.   To enable high throughput for FIFO queues, do the following:   Set DeduplicationScope to messageGroup.   Set FifoThroughputLimit to perMessageGroupId.   If you set these attributes to anything other than the values shown for enabling high throughput, normal throughput is in effect and deduplication occurs as specified. For information on throughput quotas, see Quotas related to messages in the Amazon SQS Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.queue.attribute.get_all(ctx, queue_url=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.queue.attribute.get_all queue_url=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="get_queue_attributes",
        op_kwargs={"QueueUrl": queue_url, "AttributeNames": attribute_names},
    )


async def set_(hub, ctx, queue_url: str, attributes: Dict) -> None:
    r"""
    **Autogenerated function**

    Sets the value of one or more queue attributes. When you change a queue's attributes, the change can take up to 60 seconds for most of the attributes to propagate throughout the Amazon SQS system. Changes made to the MessageRetentionPeriod attribute can take up to 15 minutes.    In the future, new attributes might be added. If you write code that calls this action, we recommend that you structure your code so that it can handle new attributes gracefully.   Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to a role and a user name in the Amazon SQS Developer Guide.   To remove the ability to change queue permissions, you must deny permission to the AddPermission, RemovePermission, and SetQueueAttributes actions in your IAM policy.

    Args:
        queue_url(str): The URL of the Amazon SQS queue whose attributes are set. Queue URLs and names are case-sensitive.
        attributes(Dict): A map of attributes to set. The following lists the names, descriptions, and values of the special request parameters that the SetQueueAttributes action uses:    DelaySeconds – The length of time, in seconds, for which the delivery of all messages in the queue is delayed. Valid values: An integer from 0 to 900 (15 minutes). Default: 0.     MaximumMessageSize – The limit of how many bytes a message can contain before Amazon SQS rejects it. Valid values: An integer from 1,024 bytes (1 KiB) up to 262,144 bytes (256 KiB). Default: 262,144 (256 KiB).     MessageRetentionPeriod – The length of time, in seconds, for which Amazon SQS retains a message. Valid values: An integer representing seconds, from 60 (1 minute) to 1,209,600 (14 days). Default: 345,600 (4 days).     Policy – The queue's policy. A valid Amazon Web Services policy. For more information about policy structure, see Overview of Amazon Web Services IAM Policies in the Identity and Access Management User Guide.     ReceiveMessageWaitTimeSeconds – The length of time, in seconds, for which a  ReceiveMessage  action waits for a message to arrive. Valid values: An integer from 0 to 20 (seconds). Default: 0.     RedrivePolicy – The string that includes the parameters for the dead-letter queue functionality of the source queue as a JSON object. For more information about the redrive policy and dead-letter queues, see Using Amazon SQS Dead-Letter Queues in the Amazon SQS Developer Guide.    deadLetterTargetArn – The Amazon Resource Name (ARN) of the dead-letter queue to which Amazon SQS moves messages after the value of maxReceiveCount is exceeded.    maxReceiveCount – The number of times a message is delivered to the source queue before being moved to the dead-letter queue. When the ReceiveCount for a message exceeds the maxReceiveCount for a queue, Amazon SQS moves the message to the dead-letter-queue.    The dead-letter queue of a FIFO queue must also be a FIFO queue. Similarly, the dead-letter queue of a standard queue must also be a standard queue.     VisibilityTimeout – The visibility timeout for the queue, in seconds. Valid values: An integer from 0 to 43,200 (12 hours). Default: 30. For more information about the visibility timeout, see Visibility Timeout in the Amazon SQS Developer Guide.   The following attributes apply only to server-side-encryption:    KmsMasterKeyId – The ID of an Amazon Web Services managed customer master key (CMK) for Amazon SQS or a custom CMK. For more information, see Key Terms. While the alias of the AWS-managed CMK for Amazon SQS is always alias/aws/sqs, the alias of a custom CMK can, for example, be alias/MyAlias . For more examples, see KeyId in the Key Management Service API Reference.     KmsDataKeyReusePeriodSeconds – The length of time, in seconds, for which Amazon SQS can reuse a data key to encrypt or decrypt messages before calling KMS again. An integer representing seconds, between 60 seconds (1 minute) and 86,400 seconds (24 hours). Default: 300 (5 minutes). A shorter time period provides better security but results in more calls to KMS which might incur charges after Free Tier. For more information, see How Does the Data Key Reuse Period Work?.    The following attribute applies only to FIFO (first-in-first-out) queues:    ContentBasedDeduplication – Enables content-based deduplication. For more information, see Exactly-once processing in the Amazon SQS Developer Guide. Note the following:    Every message must have a unique MessageDeduplicationId.   You may provide a MessageDeduplicationId explicitly.   If you aren't able to provide a MessageDeduplicationId and you enable ContentBasedDeduplication for your queue, Amazon SQS uses a SHA-256 hash to generate the MessageDeduplicationId using the body of the message (but not the attributes of the message).    If you don't provide a MessageDeduplicationId and the queue doesn't have ContentBasedDeduplication set, the action fails with an error.   If the queue has ContentBasedDeduplication set, your MessageDeduplicationId overrides the generated one.     When ContentBasedDeduplication is in effect, messages with identical content sent within the deduplication interval are treated as duplicates and only one copy of the message is delivered.   If you send one message with ContentBasedDeduplication enabled and then another message with a MessageDeduplicationId that is the same as the one generated for the first MessageDeduplicationId, the two messages are treated as duplicates and only one copy of the message is delivered.      The following attributes apply only to high throughput for FIFO queues:    DeduplicationScope – Specifies whether message deduplication occurs at the message group or queue level. Valid values are messageGroup and queue.    FifoThroughputLimit – Specifies whether the FIFO queue throughput quota applies to the entire queue or per message group. Valid values are perQueue and perMessageGroupId. The perMessageGroupId value is allowed only when the value for DeduplicationScope is messageGroup.   To enable high throughput for FIFO queues, do the following:   Set DeduplicationScope to messageGroup.   Set FifoThroughputLimit to perMessageGroupId.   If you set these attributes to anything other than the values shown for enabling high throughput, normal throughput is in effect and deduplication occurs as specified. For information on throughput quotas, see Quotas related to messages in the Amazon SQS Developer Guide.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.queue.attribute.set(ctx, queue_url=value, attributes=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.queue.attribute.set queue_url=value, attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="set_queue_attributes",
        op_kwargs={"QueueUrl": queue_url, "Attributes": attributes},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    domain_name: str,
    elasticsearch_version: str = None,
    elasticsearch_cluster_config: Dict = None,
    ebs_options: Dict = None,
    access_policies: str = None,
    snapshot_options: Dict = None,
    vpc_options: Dict = None,
    cognito_options: Dict = None,
    encryption_at_rest_options: Dict = None,
    node_to_node_encryption_options: Dict = None,
    advanced_options: Dict = None,
    log_publishing_options: Dict = None,
    domain_endpoint_options: Dict = None,
    advanced_security_options: Dict = None,
    auto_tune_options: Dict = None,
    tag_list: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Elasticsearch domain. For more information, see Creating Elasticsearch Domains in the Amazon Elasticsearch Service Developer Guide.

    Args:
        domain_name(str): The name of the Elasticsearch domain that you are creating. Domain names are unique across the domains owned by an account within an AWS region. Domain names must start with a lowercase letter and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        elasticsearch_version(str, optional): String of format X.Y to specify version for the Elasticsearch domain eg. "1.5" or "2.3". For more information, see Creating Elasticsearch Domains in the Amazon Elasticsearch Service Developer Guide. Defaults to None.
        elasticsearch_cluster_config(Dict, optional): Configuration options for an Elasticsearch domain. Specifies the instance type and number of instances in the domain cluster. . Defaults to None.
        ebs_options(Dict, optional): Options to enable, disable and specify the type and size of EBS storage volumes. . Defaults to None.
        access_policies(str, optional):  IAM access policy as a JSON-formatted string. Defaults to None.
        snapshot_options(Dict, optional): Option to set time, in UTC format, of the daily automated snapshot. Default value is 0 hours. . Defaults to None.
        vpc_options(Dict, optional): Options to specify the subnets and security groups for VPC endpoint. For more information, see Creating a VPC in VPC Endpoints for Amazon Elasticsearch Service Domains. Defaults to None.
        cognito_options(Dict, optional): Options to specify the Cognito user and identity pools for Kibana authentication. For more information, see Amazon Cognito Authentication for Kibana. Defaults to None.
        encryption_at_rest_options(Dict, optional): Specifies the Encryption At Rest Options. Defaults to None.
        node_to_node_encryption_options(Dict, optional): Specifies the NodeToNodeEncryptionOptions. Defaults to None.
        advanced_options(Dict, optional):  Option to allow references to indices in an HTTP request body. Must be false when configuring access to individual sub-resources. By default, the value is true. See Configuration Advanced Options for more information. Defaults to None.
        log_publishing_options(Dict, optional): Map of LogType and LogPublishingOption, each containing options to publish a given type of Elasticsearch log. Defaults to None.
        domain_endpoint_options(Dict, optional): Options to specify configuration that will be applied to the domain endpoint. Defaults to None.
        advanced_security_options(Dict, optional): Specifies advanced security options. Defaults to None.
        auto_tune_options(Dict, optional): Specifies Auto-Tune options. Defaults to None.
        tag_list(List, optional): A list of Tag added during domain creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.elasticsearch.domain.init.create(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.elasticsearch.domain.init.create domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="create_elasticsearch_domain",
        op_kwargs={
            "DomainName": domain_name,
            "ElasticsearchVersion": elasticsearch_version,
            "ElasticsearchClusterConfig": elasticsearch_cluster_config,
            "EBSOptions": ebs_options,
            "AccessPolicies": access_policies,
            "SnapshotOptions": snapshot_options,
            "VPCOptions": vpc_options,
            "CognitoOptions": cognito_options,
            "EncryptionAtRestOptions": encryption_at_rest_options,
            "NodeToNodeEncryptionOptions": node_to_node_encryption_options,
            "AdvancedOptions": advanced_options,
            "LogPublishingOptions": log_publishing_options,
            "DomainEndpointOptions": domain_endpoint_options,
            "AdvancedSecurityOptions": advanced_security_options,
            "AutoTuneOptions": auto_tune_options,
            "TagList": tag_list,
        },
    )


async def delete(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Permanently deletes the specified Elasticsearch domain and all of its data. Once a domain is deleted, it cannot be recovered.

    Args:
        domain_name(str): The name of the Elasticsearch domain that you want to permanently delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.elasticsearch.domain.init.delete(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.elasticsearch.domain.init.delete domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="delete_elasticsearch_domain",
        op_kwargs={"DomainName": domain_name},
    )


async def describe(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns domain configuration information about the specified Elasticsearch domain, including the domain ID, domain endpoint, and domain ARN.

    Args:
        domain_name(str): The name of the Elasticsearch domain for which you want information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.elasticsearch.domain.init.describe(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.elasticsearch.domain.init.describe domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="describe_elasticsearch_domain",
        op_kwargs={"DomainName": domain_name},
    )


async def describe_all(hub, ctx, domain_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns domain configuration information about the specified Elasticsearch domains, including the domain ID, domain endpoint, and domain ARN.

    Args:
        domain_names(List): The Elasticsearch domains for which you want information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.elasticsearch.domain.init.describe_all(
                ctx, domain_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.elasticsearch.domain.init.describe_all domain_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="describe_elasticsearch_domains",
        op_kwargs={"DomainNames": domain_names},
    )


async def upgrade(
    hub, ctx, domain_name: str, target_version: str, perform_check_only: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Allows you to either upgrade your domain or perform an Upgrade eligibility check to a compatible Elasticsearch version.

    Args:
        domain_name(str): The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        target_version(str): The version of Elasticsearch that you intend to upgrade the domain to.
        perform_check_only(bool, optional):  This flag, when set to True, indicates that an Upgrade Eligibility Check needs to be performed. This will not actually perform the Upgrade. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.elasticsearch.domain.init.upgrade(
                ctx, domain_name=value, target_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.elasticsearch.domain.init.upgrade domain_name=value, target_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="upgrade_elasticsearch_domain",
        op_kwargs={
            "DomainName": domain_name,
            "TargetVersion": target_version,
            "PerformCheckOnly": perform_check_only,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, hosted_zone_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables DNSSEC signing in a specific hosted zone. This action does not deactivate any key-signing keys (KSKs) that are active in the hosted zone.

    Args:
        hosted_zone_id(str): A unique string used to identify a hosted zone.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.hosted_zone.dnssec.disable(ctx, hosted_zone_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.hosted_zone.dnssec.disable hosted_zone_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="disable_hosted_zone_dnssec",
        op_kwargs={"HostedZoneId": hosted_zone_id},
    )


async def enable(hub, ctx, hosted_zone_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Enables DNSSEC signing in a specific hosted zone.

    Args:
        hosted_zone_id(str): A unique string used to identify a hosted zone.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.hosted_zone.dnssec.enable(ctx, hosted_zone_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.hosted_zone.dnssec.enable hosted_zone_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="enable_hosted_zone_dnssec",
        op_kwargs={"HostedZoneId": hosted_zone_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    db_instance_identifier: str,
    filename_contains: str = None,
    file_last_written: int = None,
    file_size: int = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of DB log files for the DB instance.

    Args:
        db_instance_identifier(str): The customer-assigned name of the DB instance that contains the log files you want to list. Constraints:   Must match the identifier of an existing DBInstance.  .
        filename_contains(str, optional): Filters the available log files for log file names that contain the specified string. Defaults to None.
        file_last_written(int, optional): Filters the available log files for files written since the specified date, in POSIX timestamp format with milliseconds. Defaults to None.
        file_size(int, optional): Filters the available log files for files larger than the specified size. Defaults to None.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so you can retrieve the remaining results. Defaults to None.
        marker(str, optional): The pagination token provided in the previous request. If this parameter is specified the response includes only records beyond the marker, up to MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.log_file.init.describe_all(
                ctx, db_instance_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.log_file.init.describe_all db_instance_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_db_log_files",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "FilenameContains": filename_contains,
            "FileLastWritten": file_last_written,
            "FileSize": file_size,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx) -> None:
    r"""
    **Autogenerated function**

    Deletes an Firewall Manager association with the IAM role and the Amazon Simple Notification Service (SNS) topic that is used to record Firewall Manager SNS logs.

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.notification_channel.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.notification_channel.delete
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="fms", operation="delete_notification_channel", op_kwargs={}
    )


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Information about the Amazon Simple Notification Service (SNS) topic that is used to record Firewall Manager SNS logs.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.notification_channel.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.notification_channel.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="fms", operation="get_notification_channel", op_kwargs={}
    )


async def put(hub, ctx, sns_topic_arn: str, sns_role_name: str) -> None:
    r"""
    **Autogenerated function**

    Designates the IAM role and Amazon Simple Notification Service (SNS) topic that Firewall Manager uses to record SNS logs. To perform this action outside of the console, you must configure the SNS topic to allow the Firewall Manager role AWSServiceRoleForFMS to publish SNS logs. For more information, see Firewall Manager required permissions for API actions in the Firewall Manager Developer Guide.

    Args:
        sns_topic_arn(str): The Amazon Resource Name (ARN) of the SNS topic that collects notifications from Firewall Manager.
        sns_role_name(str): The Amazon Resource Name (ARN) of the IAM role that allows Amazon SNS to record Firewall Manager activity. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.notification_channel.put(
                ctx, sns_topic_arn=value, sns_role_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.notification_channel.put sns_topic_arn=value, sns_role_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="put_notification_channel",
        op_kwargs={"SnsTopicArn": sns_topic_arn, "SnsRoleName": sns_role_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def change(
    hub,
    ctx,
    resource_type: str,
    resource_id: str,
    add_tags: List = None,
    remove_tag_keys: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds, edits, or deletes tags for a health check or a hosted zone. For information about using tags for cost allocation, see Using Cost Allocation Tags in the Billing and Cost Management User Guide.

    Args:
        resource_type(str): The type of the resource.   The resource type for health checks is healthcheck.   The resource type for hosted zones is hostedzone.  .
        resource_id(str): The ID of the resource for which you want to add, change, or delete tags.
        add_tags(List, optional): A complex type that contains a list of the tags that you want to add to the specified health check or hosted zone and/or the tags that you want to edit Value for. You can add a maximum of 10 tags to a health check or a hosted zone. Defaults to None.
        remove_tag_keys(List, optional): A complex type that contains a list of the tags that you want to delete from the specified health check or hosted zone. You can specify up to 10 keys. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.tags_for_resource.change(
                ctx, resource_type=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.tags_for_resource.change resource_type=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="change_tags_for_resource",
        op_kwargs={
            "ResourceType": resource_type,
            "ResourceId": resource_id,
            "AddTags": add_tags,
            "RemoveTagKeys": remove_tag_keys,
        },
    )


async def list_(hub, ctx, resource_type: str, resource_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists tags for one health check or hosted zone.  For information about using tags for cost allocation, see Using Cost Allocation Tags in the Billing and Cost Management User Guide.

    Args:
        resource_type(str): The type of the resource.   The resource type for health checks is healthcheck.   The resource type for hosted zones is hostedzone.  .
        resource_id(str): The ID of the resource for which you want to retrieve tags.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.tags_for_resource.list(
                ctx, resource_type=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.tags_for_resource.list resource_type=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceType": resource_type, "ResourceId": resource_id},
    )


async def list_all(hub, ctx, resource_type: str, resource_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Lists tags for up to 10 health checks or hosted zones. For information about using tags for cost allocation, see Using Cost Allocation Tags in the Billing and Cost Management User Guide.

    Args:
        resource_type(str): The type of the resources.   The resource type for health checks is healthcheck.   The resource type for hosted zones is hostedzone.  .
        resource_ids(List): A complex type that contains the ResourceId element for each resource for which you want to get a list of tags.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.tags_for_resource.list_all(
                ctx, resource_type=value, resource_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.tags_for_resource.list_all resource_type=value, resource_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_tags_for_resources",
        op_kwargs={"ResourceType": resource_type, "ResourceIds": resource_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, connection_id: str) -> None:
    r"""
    **Autogenerated function**

    Delete the connection with the provided id.

    Args:
        connection_id(str): .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewaymanagementapi.connection.delete(
                ctx, connection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewaymanagementapi.connection.delete connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewaymanagementapi",
        operation="delete_connection",
        op_kwargs={"ConnectionId": connection_id},
    )


async def get(hub, ctx, connection_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get information about the connection with the provided id.

    Args:
        connection_id(str): .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewaymanagementapi.connection.get(ctx, connection_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewaymanagementapi.connection.get connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewaymanagementapi",
        operation="get_connection",
        op_kwargs={"ConnectionId": connection_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub, ctx, copy_product_token: str, accept_language: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the status of the specified copy product operation.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        copy_product_token(str): The token for the copy product operation. This token is returned by CopyProduct.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.copy_product_status.describe(
                ctx, copy_product_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.copy_product_status.describe copy_product_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_copy_product_status",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "CopyProductToken": copy_product_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(
    hub,
    ctx,
    directory_arn: str,
    parent_reference: Dict,
    child_reference: Dict,
    link_name: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Attaches an existing object to another object. An object can be accessed in two ways:   Using the path   Using ObjectIdentifier

    Args:
        directory_arn(str): Amazon Resource Name (ARN) that is associated with the Directory where both objects reside. For more information, see arns.
        parent_reference(Dict): The parent object reference.
        child_reference(Dict): The child object reference to be attached to the object.
        link_name(str): The link name with which the child object is attached to the parent.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.object_.init.attach(
                ctx,
                directory_arn=value,
                parent_reference=value,
                child_reference=value,
                link_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.object_.init.attach directory_arn=value, parent_reference=value, child_reference=value, link_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="attach_object",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "ParentReference": parent_reference,
            "ChildReference": child_reference,
            "LinkName": link_name,
        },
    )


async def create(
    hub,
    ctx,
    directory_arn: str,
    schema_facets: List,
    object_attribute_list: List = None,
    parent_reference: Dict = None,
    link_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an object in a Directory. Additionally attaches the object to a parent, if a parent reference and LinkName is specified. An object is simply a collection of Facet attributes. You can also use this API call to create a policy object, if the facet from which you create the object is a policy facet.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory in which the object will be created. For more information, see arns.
        schema_facets(List): A list of schema facets to be associated with the object. Do not provide minor version components. See SchemaFacet for details.
        object_attribute_list(List, optional): The attribute map whose attribute ARN contains the key and attribute value as the map value. Defaults to None.
        parent_reference(Dict, optional): If specified, the parent reference to which this object will be attached. Defaults to None.
        link_name(str, optional): The name of link that is used to attach this object to a parent. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.object_.init.create(
                ctx, directory_arn=value, schema_facets=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.object_.init.create directory_arn=value, schema_facets=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="create_object",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "SchemaFacets": schema_facets,
            "ObjectAttributeList": object_attribute_list,
            "ParentReference": parent_reference,
            "LinkName": link_name,
        },
    )


async def delete(hub, ctx, directory_arn: str, object_reference: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an object and its associated attributes. Only objects with no children and no parents can be deleted. The maximum number of attributes that can be deleted during an object deletion is 30. For more information, see Amazon Cloud Directory Limits.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory where the object resides. For more information, see arns.
        object_reference(Dict): A reference that identifies the object.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.object_.init.delete(
                ctx, directory_arn=value, object_reference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.object_.init.delete directory_arn=value, object_reference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="delete_object",
        op_kwargs={"DirectoryArn": directory_arn, "ObjectReference": object_reference},
    )


async def detach(
    hub, ctx, directory_arn: str, parent_reference: Dict, link_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Detaches a given object from the parent object. The object that is to be detached from the parent is specified by the link name.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory where objects reside. For more information, see arns.
        parent_reference(Dict): The parent reference from which the object with the specified link name is detached.
        link_name(str): The link name associated with the object that needs to be detached.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.object_.init.detach(
                ctx, directory_arn=value, parent_reference=value, link_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.object_.init.detach directory_arn=value, parent_reference=value, link_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="detach_object",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "ParentReference": parent_reference,
            "LinkName": link_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub, ctx, accept_language: str = None, id_: str = None, name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified provisioned product.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str, optional): The provisioned product identifier. You must provide the name or ID, but not both. If you do not provide a name or ID, or you provide both name and ID, an InvalidParametersException will occur. Defaults to None.
        name(str, optional): The name of the provisioned product. You must provide the name or ID, but not both. If you do not provide a name or ID, or you provide both name and ID, an InvalidParametersException will occur. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioned_product.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioned_product.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_provisioned_product",
        op_kwargs={"AcceptLanguage": accept_language, "Id": id_, "Name": name},
    )


async def scan(
    hub,
    ctx,
    accept_language: str = None,
    access_level_filter: Dict = None,
    page_size: int = None,
    page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the provisioned products that are available (not terminated). To use additional filtering, see SearchProvisionedProducts.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        access_level_filter(Dict, optional): The access level to use to obtain results. The default is User. Defaults to None.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioned_product.init.scan(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioned_product.init.scan
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="scan_provisioned_products",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "AccessLevelFilter": access_level_filter,
            "PageSize": page_size,
            "PageToken": page_token,
        },
    )


async def search(
    hub,
    ctx,
    accept_language: str = None,
    access_level_filter: Dict = None,
    filters: Dict = None,
    sort_by: str = None,
    sort_order: str = None,
    page_size: int = None,
    page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the provisioned products that meet the specified criteria.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        access_level_filter(Dict, optional): The access level to use to obtain results. The default is User. Defaults to None.
        filters(Dict, optional): The search filters. When the key is SearchQuery, the searchable fields are arn, createdTime, id, lastRecordId, idempotencyToken, name, physicalId, productId, provisioningArtifact, type, status, tags, userArn, userArnSession, lastProvisioningRecordId, lastSuccessfulProvisioningRecordId, productName, and provisioningArtifactName. Example: "SearchQuery":["status:AVAILABLE"] . Defaults to None.
        sort_by(str, optional): The sort field. If no value is specified, the results are not sorted. The valid values are arn, id, name, and lastRecordId. Defaults to None.
        sort_order(str, optional): The sort order. If no value is specified, the results are not sorted. Defaults to None.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioned_product.init.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioned_product.init.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="search_provisioned_products",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "AccessLevelFilter": access_level_filter,
            "Filters": filters,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "PageSize": page_size,
            "PageToken": page_token,
        },
    )


async def terminate(
    hub,
    ctx,
    terminate_token: str,
    provisioned_product_name: str = None,
    provisioned_product_id: str = None,
    ignore_errors: bool = None,
    accept_language: str = None,
    retain_physical_resources: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Terminates the specified provisioned product. This operation does not delete any records associated with the provisioned product. You can check the status of this request using DescribeRecord.

    Args:
        provisioned_product_name(str, optional): The name of the provisioned product. You cannot specify both ProvisionedProductName and ProvisionedProductId. Defaults to None.
        provisioned_product_id(str, optional): The identifier of the provisioned product. You cannot specify both ProvisionedProductName and ProvisionedProductId. Defaults to None.
        terminate_token(str): An idempotency token that uniquely identifies the termination request. This token is only valid during the termination process. After the provisioned product is terminated, subsequent requests to terminate the same provisioned product always return ResourceNotFound.
        ignore_errors(bool, optional): If set to true, AWS Service Catalog stops managing the specified provisioned product even if it cannot delete the underlying resources. Defaults to None.
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        retain_physical_resources(bool, optional): When this boolean parameter is set to true, the TerminateProvisionedProduct API deletes the Service Catalog provisioned product. However, it does not remove the CloudFormation stack, stack set, or the underlying resources of the deleted provisioned product. The default value is false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioned_product.init.terminate(
                ctx, terminate_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioned_product.init.terminate terminate_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="terminate_provisioned_product",
        op_kwargs={
            "ProvisionedProductName": provisioned_product_name,
            "ProvisionedProductId": provisioned_product_id,
            "TerminateToken": terminate_token,
            "IgnoreErrors": ignore_errors,
            "AcceptLanguage": accept_language,
            "RetainPhysicalResources": retain_physical_resources,
        },
    )


async def update(
    hub,
    ctx,
    update_token: str,
    accept_language: str = None,
    provisioned_product_name: str = None,
    provisioned_product_id: str = None,
    product_id: str = None,
    product_name: str = None,
    provisioning_artifact_id: str = None,
    provisioning_artifact_name: str = None,
    path_id: str = None,
    path_name: str = None,
    provisioning_parameters: List = None,
    provisioning_preferences: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Requests updates to the configuration of the specified provisioned product. If there are tags associated with the object, they cannot be updated or added. Depending on the specific updates requested, this operation can update with no interruption, with some interruption, or replace the provisioned product entirely. You can check the status of this request using DescribeRecord.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        provisioned_product_name(str, optional): The name of the provisioned product. You cannot specify both ProvisionedProductName and ProvisionedProductId. Defaults to None.
        provisioned_product_id(str, optional): The identifier of the provisioned product. You must provide the name or ID, but not both. Defaults to None.
        product_id(str, optional): The identifier of the product. You must provide the name or ID, but not both. Defaults to None.
        product_name(str, optional): The name of the product. You must provide the name or ID, but not both. Defaults to None.
        provisioning_artifact_id(str, optional): The identifier of the provisioning artifact. Defaults to None.
        provisioning_artifact_name(str, optional): The name of the provisioning artifact. You must provide the name or ID, but not both. Defaults to None.
        path_id(str, optional): The path identifier. This value is optional if the product has a default path, and required if the product has more than one path. You must provide the name or ID, but not both. Defaults to None.
        path_name(str, optional): The name of the path. You must provide the name or ID, but not both. Defaults to None.
        provisioning_parameters(List, optional): The new parameters. Defaults to None.
        provisioning_preferences(Dict, optional): An object that contains information about the provisioning preferences for a stack set. Defaults to None.
        tags(List, optional): One or more tags. Requires the product to have RESOURCE_UPDATE constraint with TagUpdatesOnProvisionedProduct set to ALLOWED to allow tag updates. Defaults to None.
        update_token(str): The idempotency token that uniquely identifies the provisioning update request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioned_product.init.update(
                ctx, update_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioned_product.init.update update_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="update_provisioned_product",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "ProvisionedProductName": provisioned_product_name,
            "ProvisionedProductId": provisioned_product_id,
            "ProductId": product_id,
            "ProductName": product_name,
            "ProvisioningArtifactId": provisioning_artifact_id,
            "ProvisioningArtifactName": provisioning_artifact_name,
            "PathId": path_id,
            "PathName": path_name,
            "ProvisioningParameters": provisioning_parameters,
            "ProvisioningPreferences": provisioning_preferences,
            "Tags": tags,
            "UpdateToken": update_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, name: str, attributes: Dict = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a topic to which notifications can be published. Users can create at most 100,000 standard topics (at most 1,000 FIFO topics). For more information, see Creating an Amazon SNS topic in the Amazon SNS Developer Guide. This action is idempotent, so if the requester already owns a topic with the specified name, that topic's ARN is returned without creating a new topic.

    Args:
        name(str): The name of the topic you want to create. Constraints: Topic names must be made up of only uppercase and lowercase ASCII letters, numbers, underscores, and hyphens, and must be between 1 and 256 characters long. For a FIFO (first-in-first-out) topic, the name must end with the .fifo suffix. .
        attributes(Dict, optional): A map of attributes with their corresponding values. The following lists the names, descriptions, and values of the special request parameters that the CreateTopic action uses:    DeliveryPolicy – The policy that defines how Amazon SNS retries failed deliveries to HTTP/S endpoints.    DisplayName – The display name to use for a topic with SMS subscriptions.    FifoTopic – Set to true to create a FIFO topic.    Policy – The policy that defines who can access your topic. By default, only the topic owner can publish or subscribe to the topic.   The following attribute applies only to server-side encryption:    KmsMasterKeyId – The ID of an Amazon Web Services managed customer master key (CMK) for Amazon SNS or a custom CMK. For more information, see Key Terms. For more examples, see KeyId in the Key Management Service API Reference.    The following attributes apply only to FIFO topics:    FifoTopic – When this is set to true, a FIFO topic is created.    ContentBasedDeduplication – Enables content-based deduplication for FIFO topics.   By default, ContentBasedDeduplication is set to false. If you create a FIFO topic and this attribute is false, you must specify a value for the MessageDeduplicationId parameter for the Publish action.    When you set ContentBasedDeduplication to true, Amazon SNS uses a SHA-256 hash to generate the MessageDeduplicationId using the body of the message (but not the attributes of the message). (Optional) To override the generated value, you can specify a value for the MessageDeduplicationId parameter for the Publish action.    . Defaults to None.
        tags(List, optional): The list of tags to add to a new topic.  To be able to tag a topic on creation, you must have the sns:CreateTopic and sns:TagResource permissions. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.topic.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.topic.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="create_topic",
        op_kwargs={"Name": name, "Attributes": attributes, "Tags": tags},
    )


async def delete(hub, ctx, topic_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a topic and all its subscriptions. Deleting a topic might prevent some messages previously sent to the topic from being delivered to subscribers. This action is idempotent, so deleting a topic that does not exist does not result in an error.

    Args:
        topic_arn(str): The ARN of the topic you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.topic.init.delete(ctx, topic_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.topic.init.delete topic_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="delete_topic",
        op_kwargs={"TopicArn": topic_arn},
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the requester's topics. Each call returns a limited list of topics, up to 100. If there are more topics, a NextToken is also returned. Use the NextToken parameter in a new ListTopics call to get further results. This action is throttled at 30 transactions per second (TPS).

    Args:
        next_token(str, optional): Token returned by the previous ListTopics request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.topic.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.topic.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="list_topics",
        op_kwargs={"NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(hub, ctx, name: str, value: str) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an account setting for all IAM users on an account for whom no individual account setting has been specified. Account settings are set on a per-Region basis.

    Args:
        name(str): The resource name for which to modify the account setting. If serviceLongArnFormat is specified, the ARN for your Amazon ECS services is affected. If taskLongArnFormat is specified, the ARN and resource ID for your Amazon ECS tasks is affected. If containerInstanceLongArnFormat is specified, the ARN and resource ID for your Amazon ECS container instances is affected. If awsvpcTrunking is specified, the ENI limit for your Amazon ECS container instances is affected. If containerInsights is specified, the default setting for CloudWatch Container Insights for your clusters is affected.
        value(str): The account setting value for the specified principal ARN. Accepted values are enabled and disabled.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.account_setting.default.put(ctx, name=value, value=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.account_setting.default.put name=value, value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="put_account_setting_default",
        op_kwargs={"name": name, "value": value},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, auto_scaling_group_name: str, topic_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified notification.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        topic_arn(str): The Amazon Resource Name (ARN) of the Amazon Simple Notification Service (Amazon SNS) topic.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.notification_configuration.delete(
                ctx, auto_scaling_group_name=value, topic_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.notification_configuration.delete auto_scaling_group_name=value, topic_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="delete_notification_configuration",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "TopicARN": topic_arn,
        },
    )


async def describe_all(
    hub,
    ctx,
    auto_scaling_group_names: List = None,
    next_token: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the Amazon SNS notifications that are configured for one or more Auto Scaling groups.

    Args:
        auto_scaling_group_names(List, optional): The name of the Auto Scaling group. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_records(int, optional): The maximum number of items to return with this call. The default value is 50 and the maximum value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.notification_configuration.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.notification_configuration.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_notification_configurations",
        op_kwargs={
            "AutoScalingGroupNames": auto_scaling_group_names,
            "NextToken": next_token,
            "MaxRecords": max_records,
        },
    )


async def put(
    hub, ctx, auto_scaling_group_name: str, topic_arn: str, notification_types: List
) -> None:
    r"""
    **Autogenerated function**

    Configures an Auto Scaling group to send notifications when specified events take place. Subscribers to the specified topic can have messages delivered to an endpoint such as a web server or an email address. This configuration overwrites any existing configuration. For more information, see Getting Amazon SNS notifications when your Auto Scaling group scales in the Amazon EC2 Auto Scaling User Guide. If you exceed your maximum limit of SNS topics, which is 10 per Auto Scaling group, the call fails.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        topic_arn(str): The Amazon Resource Name (ARN) of the Amazon Simple Notification Service (Amazon SNS) topic.
        notification_types(List): The type of event that causes the notification to be sent. To query the notification types supported by Amazon EC2 Auto Scaling, call the DescribeAutoScalingNotificationTypes API.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.notification_configuration.put(
                ctx, auto_scaling_group_name=value, topic_arn=value, notification_types=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.notification_configuration.put auto_scaling_group_name=value, topic_arn=value, notification_types=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="put_notification_configuration",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "TopicARN": topic_arn,
            "NotificationTypes": notification_types,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    sources: List,
    simulation_software_suite: Dict,
    robot_software_suite: Dict,
    rendering_engine: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a simulation application.

    Args:
        name(str): The name of the simulation application.
        sources(List): The sources of the simulation application.
        simulation_software_suite(Dict): The simulation software suite used by the simulation application.
        robot_software_suite(Dict): The robot software suite (ROS distribution) used by the simulation application.
        rendering_engine(Dict, optional): The rendering engine for the simulation application. Defaults to None.
        tags(Dict, optional): A map that contains tag keys and tag values that are attached to the simulation application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.application.init.create(
                ctx,
                name=value,
                sources=value,
                simulation_software_suite=value,
                robot_software_suite=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.application.init.create name=value, sources=value, simulation_software_suite=value, robot_software_suite=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="create_simulation_application",
        op_kwargs={
            "name": name,
            "sources": sources,
            "simulationSoftwareSuite": simulation_software_suite,
            "robotSoftwareSuite": robot_software_suite,
            "renderingEngine": rendering_engine,
            "tags": tags,
        },
    )


async def delete(hub, ctx, application: str, application_version: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a simulation application.

    Args:
        application(str): The application information for the simulation application to delete.
        application_version(str, optional): The version of the simulation application to delete. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.application.init.delete(
                ctx, application=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.application.init.delete application=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="delete_simulation_application",
        op_kwargs={
            "application": application,
            "applicationVersion": application_version,
        },
    )


async def describe(hub, ctx, application: str, application_version: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes a simulation application.

    Args:
        application(str): The application information for the simulation application.
        application_version(str, optional): The version of the simulation application to describe. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.application.init.describe(
                ctx, application=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.application.init.describe application=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="describe_simulation_application",
        op_kwargs={
            "application": application,
            "applicationVersion": application_version,
        },
    )


async def list_all(
    hub,
    ctx,
    version_qualifier: str = None,
    next_token: str = None,
    max_results: int = None,
    filters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of simulation applications. You can optionally provide filters to retrieve specific simulation applications.

    Args:
        version_qualifier(str, optional): The version qualifier of the simulation application. Defaults to None.
        next_token(str, optional): If the previous paginated request did not return all of the remaining results, the response object's nextToken parameter value is set to a token. To retrieve the next set of results, call ListSimulationApplications again and assign that token to the request object's nextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. . Defaults to None.
        max_results(int, optional): When this parameter is used, ListSimulationApplications only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListSimulationApplications request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then ListSimulationApplications returns up to 100 results and a nextToken value if applicable. . Defaults to None.
        filters(List, optional): Optional list of filters to limit results. The filter name name is supported. When filtering, you must use the complete value of the filtered item. You can use up to three filters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.application.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.application.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="list_simulation_applications",
        op_kwargs={
            "versionQualifier": version_qualifier,
            "nextToken": next_token,
            "maxResults": max_results,
            "filters": filters,
        },
    )


async def update(
    hub,
    ctx,
    application: str,
    sources: List,
    simulation_software_suite: Dict,
    robot_software_suite: Dict,
    rendering_engine: Dict = None,
    current_revision_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a simulation application.

    Args:
        application(str): The application information for the simulation application.
        sources(List): The sources of the simulation application.
        simulation_software_suite(Dict): The simulation software suite used by the simulation application.
        robot_software_suite(Dict): Information about the robot software suite (ROS distribution).
        rendering_engine(Dict, optional): The rendering engine for the simulation application. Defaults to None.
        current_revision_id(str, optional): The revision id for the robot application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.application.init.update(
                ctx,
                application=value,
                sources=value,
                simulation_software_suite=value,
                robot_software_suite=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.application.init.update application=value, sources=value, simulation_software_suite=value, robot_software_suite=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="update_simulation_application",
        op_kwargs={
            "application": application,
            "sources": sources,
            "simulationSoftwareSuite": simulation_software_suite,
            "robotSoftwareSuite": robot_software_suite,
            "renderingEngine": rendering_engine,
            "currentRevisionId": current_revision_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    role: str,
    targets: Dict,
    database_name: str = None,
    description: str = None,
    schedule: str = None,
    classifiers: List = None,
    table_prefix: str = None,
    schema_change_policy: Dict = None,
    recrawl_policy: Dict = None,
    lineage_configuration: Dict = None,
    configuration: str = None,
    crawler_security_configuration: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new crawler with specified targets, role, configuration, and optional schedule. At least one crawl target must be specified, in the s3Targets field, the jdbcTargets field, or the DynamoDBTargets field.

    Args:
        name(str): Name of the new crawler.
        role(str): The IAM role or Amazon Resource Name (ARN) of an IAM role used by the new crawler to access customer resources.
        database_name(str, optional): The Glue database where results are written, such as: arn:aws:daylight:us-east-1::database/sometable/*. Defaults to None.
        description(str, optional): A description of the new crawler. Defaults to None.
        targets(Dict): A list of collection of targets to crawl.
        schedule(str, optional): A cron expression used to specify the schedule (see Time-Based Schedules for Jobs and Crawlers. For example, to run something every day at 12:15 UTC, you would specify: cron(15 12 * * ? *). Defaults to None.
        classifiers(List, optional): A list of custom classifiers that the user has registered. By default, all built-in classifiers are included in a crawl, but these custom classifiers always override the default classifiers for a given classification. Defaults to None.
        table_prefix(str, optional): The table prefix used for catalog tables that are created. Defaults to None.
        schema_change_policy(Dict, optional): The policy for the crawler's update and deletion behavior. Defaults to None.
        recrawl_policy(Dict, optional): A policy that specifies whether to crawl the entire dataset again, or to crawl only folders that were added since the last crawler run. Defaults to None.
        lineage_configuration(Dict, optional): Specifies data lineage configuration settings for the crawler. Defaults to None.
        configuration(str, optional): Crawler configuration information. This versioned JSON string allows users to specify aspects of a crawler's behavior. For more information, see Configuring a Crawler. Defaults to None.
        crawler_security_configuration(str, optional): The name of the SecurityConfiguration structure to be used by this crawler. Defaults to None.
        tags(Dict, optional): The tags to use with this crawler request. You may use tags to limit access to the crawler. For more information about tags in Glue, see Amazon Web Services Tags in Glue in the developer guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.crawler.init.create(
                ctx, name=value, role=value, targets=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.crawler.init.create name=value, role=value, targets=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_crawler",
        op_kwargs={
            "Name": name,
            "Role": role,
            "DatabaseName": database_name,
            "Description": description,
            "Targets": targets,
            "Schedule": schedule,
            "Classifiers": classifiers,
            "TablePrefix": table_prefix,
            "SchemaChangePolicy": schema_change_policy,
            "RecrawlPolicy": recrawl_policy,
            "LineageConfiguration": lineage_configuration,
            "Configuration": configuration,
            "CrawlerSecurityConfiguration": crawler_security_configuration,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a specified crawler from the Glue Data Catalog, unless the crawler state is RUNNING.

    Args:
        name(str): The name of the crawler to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.crawler.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.crawler.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="glue", operation="delete_crawler", op_kwargs={"Name": name}
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves metadata for a specified crawler.

    Args:
        name(str): The name of the crawler to retrieve metadata for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.crawler.init.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.crawler.init.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="glue", operation="get_crawler", op_kwargs={"Name": name}
    )


async def get_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves metadata for all crawlers defined in the customer account.

    Args:
        max_results(int, optional): The number of crawlers to return on each call. Defaults to None.
        next_token(str, optional): A continuation token, if this is a continuation request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.crawler.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.crawler.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_crawlers",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def list_all(
    hub, ctx, max_results: int = None, next_token: str = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the names of all crawler resources in this Amazon Web Services account, or the resources with the specified tag. This operation allows you to see which resources are available in your account, and their names. This operation takes the optional Tags field, which you can use as a filter on the response so that tagged resources can be retrieved as a group. If you choose to use tags filtering, only resources with the tag are retrieved.

    Args:
        max_results(int, optional): The maximum size of a list to return. Defaults to None.
        next_token(str, optional): A continuation token, if this is a continuation request. Defaults to None.
        tags(Dict, optional): Specifies to return only these tagged resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.crawler.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.crawler.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="list_crawlers",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token, "Tags": tags},
    )


async def start(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts a crawl using the specified crawler, regardless of what is scheduled. If the crawler is already running, returns a CrawlerRunningException.

    Args:
        name(str): Name of the crawler to start.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.crawler.init.start(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.crawler.init.start name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="glue", operation="start_crawler", op_kwargs={"Name": name}
    )


async def stop(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    If the specified crawler is running, stops the crawl.

    Args:
        name(str): Name of the crawler to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.crawler.init.stop(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.crawler.init.stop name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="glue", operation="stop_crawler", op_kwargs={"Name": name}
    )


async def update(
    hub,
    ctx,
    name: str,
    role: str = None,
    database_name: str = None,
    description: str = None,
    targets: Dict = None,
    schedule: str = None,
    classifiers: List = None,
    table_prefix: str = None,
    schema_change_policy: Dict = None,
    recrawl_policy: Dict = None,
    lineage_configuration: Dict = None,
    configuration: str = None,
    crawler_security_configuration: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a crawler. If a crawler is running, you must stop it using StopCrawler before updating it.

    Args:
        name(str): Name of the new crawler.
        role(str, optional): The IAM role or Amazon Resource Name (ARN) of an IAM role that is used by the new crawler to access customer resources. Defaults to None.
        database_name(str, optional): The Glue database where results are stored, such as: arn:aws:daylight:us-east-1::database/sometable/*. Defaults to None.
        description(str, optional): A description of the new crawler. Defaults to None.
        targets(Dict, optional): A list of targets to crawl. Defaults to None.
        schedule(str, optional): A cron expression used to specify the schedule (see Time-Based Schedules for Jobs and Crawlers. For example, to run something every day at 12:15 UTC, you would specify: cron(15 12 * * ? *). Defaults to None.
        classifiers(List, optional): A list of custom classifiers that the user has registered. By default, all built-in classifiers are included in a crawl, but these custom classifiers always override the default classifiers for a given classification. Defaults to None.
        table_prefix(str, optional): The table prefix used for catalog tables that are created. Defaults to None.
        schema_change_policy(Dict, optional): The policy for the crawler's update and deletion behavior. Defaults to None.
        recrawl_policy(Dict, optional): A policy that specifies whether to crawl the entire dataset again, or to crawl only folders that were added since the last crawler run. Defaults to None.
        lineage_configuration(Dict, optional): Specifies data lineage configuration settings for the crawler. Defaults to None.
        configuration(str, optional): Crawler configuration information. This versioned JSON string allows users to specify aspects of a crawler's behavior. For more information, see Configuring a Crawler. Defaults to None.
        crawler_security_configuration(str, optional): The name of the SecurityConfiguration structure to be used by this crawler. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.crawler.init.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.crawler.init.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_crawler",
        op_kwargs={
            "Name": name,
            "Role": role,
            "DatabaseName": database_name,
            "Description": description,
            "Targets": targets,
            "Schedule": schedule,
            "Classifiers": classifiers,
            "TablePrefix": table_prefix,
            "SchemaChangePolicy": schema_change_policy,
            "RecrawlPolicy": recrawl_policy,
            "LineageConfiguration": lineage_configuration,
            "Configuration": configuration,
            "CrawlerSecurityConfiguration": crawler_security_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, listener_arn: str, certificates: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds the specified SSL server certificate to the certificate list for the specified HTTPS or TLS listener. If the certificate in already in the certificate list, the call is successful but the certificate is not added again. For more information, see HTTPS listeners in the Application Load Balancers Guide or TLS listeners in the Network Load Balancers Guide.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener.
        certificates(List): The certificate to add. You can specify one certificate per call. Set CertificateArn to the certificate ARN but do not set IsDefault.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.listener.certificate.add(
                ctx, listener_arn=value, certificates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.listener.certificate.add listener_arn=value, certificates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="add_listener_certificates",
        op_kwargs={"ListenerArn": listener_arn, "Certificates": certificates},
    )


async def describe_all(
    hub, ctx, listener_arn: str, marker: str = None, page_size: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the default certificate and the certificate list for the specified HTTPS or TLS listener. If the default certificate is also in the certificate list, it appears twice in the results (once with IsDefault set to true and once with IsDefault set to false). For more information, see SSL certificates in the Application Load Balancers Guide or Server certificates in the Network Load Balancers Guide.

    Args:
        listener_arn(str): The Amazon Resource Names (ARN) of the listener.
        marker(str, optional): The marker for the next set of results. (You received this marker from a previous call.). Defaults to None.
        page_size(int, optional): The maximum number of results to return with this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.listener.certificate.describe_all(ctx, listener_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.listener.certificate.describe_all listener_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="describe_listener_certificates",
        op_kwargs={
            "ListenerArn": listener_arn,
            "Marker": marker,
            "PageSize": page_size,
        },
    )


async def remove(hub, ctx, listener_arn: str, certificates: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified certificate from the certificate list for the specified HTTPS or TLS listener.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener.
        certificates(List): The certificate to remove. You can specify one certificate per call. Set CertificateArn to the certificate ARN but do not set IsDefault.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.listener.certificate.remove(
                ctx, listener_arn=value, certificates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.listener.certificate.remove listener_arn=value, certificates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="remove_listener_certificates",
        op_kwargs={"ListenerArn": listener_arn, "Certificates": certificates},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more tags to an Athena resource. A tag is a label that you assign to a resource. In Athena, a resource can be a workgroup or data catalog. Each tag consists of a key and an optional value, both of which you define. For example, you can use tags to categorize Athena workgroups or data catalogs by purpose, owner, or environment. Use a consistent set of tag keys to make it easier to search and filter workgroups or data catalogs in your account. For best practices, see Tagging Best Practices. Tag keys can be from 1 to 128 UTF-8 Unicode characters, and tag values can be from 0 to 256 UTF-8 Unicode characters. Tags can use letters and numbers representable in UTF-8, and the following characters: + - = . _ : / @. Tag keys and values are case-sensitive. Tag keys must be unique per resource. If you specify more than one tag, separate them by commas.

    Args:
        resource_arn(str): Specifies the ARN of the Athena resource (workgroup or data catalog) to which tags are to be added.
        tags(List): A collection of one or more tags, separated by commas, to be added to an Athena workgroup or data catalog resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more tags from a data catalog or workgroup resource.

    Args:
        resource_arn(str): Specifies the ARN of the resource from which tags are to be removed.
        tag_keys(List): A comma-separated list of one or more tag keys whose tags are to be removed from the specified resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    user_pool_id: str,
    group_name: str,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the users in the specified group. Calling this action requires developer credentials.

    Args:
        user_pool_id(str): The user pool ID for the user pool.
        group_name(str): The name of the group.
        limit(int, optional): The limit of the request to list users. Defaults to None.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.in_group.list(
                ctx, user_pool_id=value, group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.in_group.list user_pool_id=value, group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="list_users_in_group",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "GroupName": group_name,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the license configurations for the specified resource.

    Args:
        resource_arn(str): Amazon Resource Name (ARN) of a resource that has an associated license configuration.
        max_results(int, optional): Maximum number of results to return in a single call. Defaults to None.
        next_token(str, optional): Token for the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.license_.specification_for_resource.list(
                ctx, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.license_.specification_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="list_license_specifications_for_resource",
        op_kwargs={
            "ResourceArn": resource_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    resource_arn: str,
    add_license_specifications: List = None,
    remove_license_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds or removes the specified license configurations for the specified AWS resource. You can update the license specifications of AMIs, instances, and hosts. You cannot update the license specifications for launch templates and AWS CloudFormation templates, as they send license configurations to the operation that creates the resource.

    Args:
        resource_arn(str): Amazon Resource Name (ARN) of the AWS resource.
        add_license_specifications(List, optional): ARNs of the license configurations to add. Defaults to None.
        remove_license_specifications(List, optional): ARNs of the license configurations to remove. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.license_.specification_for_resource.update(
                ctx, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.license_.specification_for_resource.update resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="update_license_specifications_for_resource",
        op_kwargs={
            "ResourceArn": resource_arn,
            "AddLicenseSpecifications": add_license_specifications,
            "RemoveLicenseSpecifications": remove_license_specifications,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    application_name: str,
    url_type: str,
    session_expiration_duration_in_seconds: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates and returns a URL that you can use to connect to an application's extension. Currently, the only available extension is the Apache Flink dashboard. The IAM role or user used to call this API defines the permissions to access the extension. After the presigned URL is created, no additional permission is required to access this URL. IAM authorization policies for this API are also enforced for every HTTP request that attempts to connect to the extension.  You control the amount of time that the URL will be valid using the SessionExpirationDurationInSeconds parameter. If you do not provide this parameter, the returned URL is valid for twelve hours.  The URL that you get from a call to CreateApplicationPresignedUrl must be used within 3 minutes to be valid. If you first try to use the URL after the 3-minute limit expires, the service returns an HTTP 403 Forbidden error.

    Args:
        application_name(str): The name of the application.
        url_type(str): The type of the extension for which to create and return a URL. Currently, the only valid extension URL type is FLINK_DASHBOARD_URL. .
        session_expiration_duration_in_seconds(int, optional): The duration in seconds for which the returned URL will be valid. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.presigned_url.create(
                ctx, application_name=value, url_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.presigned_url.create application_name=value, url_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="create_application_presigned_url",
        op_kwargs={
            "ApplicationName": application_name,
            "UrlType": url_type,
            "SessionExpirationDurationInSeconds": session_expiration_duration_in_seconds,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, account_id: str, budget: Dict, notifications_with_subscribers: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a budget and, if included, notifications and subscribers.   Only one of BudgetLimit or PlannedBudgetLimits can be present in the syntax at one time. Use the syntax that matches your case. The Request Syntax section shows the BudgetLimit syntax. For PlannedBudgetLimits, see the Examples section.

    Args:
        account_id(str): The accountId that is associated with the budget.
        budget(Dict): The budget object that you want to create.
        notifications_with_subscribers(List, optional): A notification that you want to associate with a budget. A budget can have up to five notifications, and each notification can have one SNS subscriber and up to 10 email subscribers. If you include notifications and subscribers in your CreateBudget call, AWS creates the notifications and subscribers for you. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.budget.budget.init.create(ctx, account_id=value, budget=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.budget.budget.init.create account_id=value, budget=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="budgets",
        operation="create_budget",
        op_kwargs={
            "AccountId": account_id,
            "Budget": budget,
            "NotificationsWithSubscribers": notifications_with_subscribers,
        },
    )


async def delete(hub, ctx, account_id: str, budget_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a budget. You can delete your budget at any time.  Deleting a budget also deletes the notifications and subscribers that are associated with that budget.

    Args:
        account_id(str): The accountId that is associated with the budget that you want to delete.
        budget_name(str): The name of the budget that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.budget.budget.init.delete(
                ctx, account_id=value, budget_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.budget.budget.init.delete account_id=value, budget_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="budgets",
        operation="delete_budget",
        op_kwargs={"AccountId": account_id, "BudgetName": budget_name},
    )


async def describe(hub, ctx, account_id: str, budget_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a budget.  The Request Syntax section shows the BudgetLimit syntax. For PlannedBudgetLimits, see the Examples section.

    Args:
        account_id(str): The accountId that is associated with the budget that you want a description of.
        budget_name(str): The name of the budget that you want a description of.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.budget.budget.init.describe(
                ctx, account_id=value, budget_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.budget.budget.init.describe account_id=value, budget_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="budgets",
        operation="describe_budget",
        op_kwargs={"AccountId": account_id, "BudgetName": budget_name},
    )


async def describe_all(
    hub, ctx, account_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the budgets that are associated with an account.  The Request Syntax section shows the BudgetLimit syntax. For PlannedBudgetLimits, see the Examples section.

    Args:
        account_id(str): The accountId that is associated with the budgets that you want descriptions of.
        max_results(int, optional): An optional integer that represents how many entries a paginated response contains. The maximum is 100. Defaults to None.
        next_token(str, optional): The pagination token that you include in your request to indicate the next set of results that you want to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.budget.budget.init.describe_all(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.budget.budget.init.describe_all account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="budgets",
        operation="describe_budgets",
        op_kwargs={
            "AccountId": account_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(hub, ctx, account_id: str, new_budget: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Updates a budget. You can change every part of a budget except for the budgetName and the calculatedSpend. When you modify a budget, the calculatedSpend drops to zero until AWS has new usage data to use for forecasting.  Only one of BudgetLimit or PlannedBudgetLimits can be present in the syntax at one time. Use the syntax that matches your case. The Request Syntax section shows the BudgetLimit syntax. For PlannedBudgetLimits, see the Examples section.

    Args:
        account_id(str): The accountId that is associated with the budget that you want to update.
        new_budget(Dict): The budget that you want to update your budget to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.budget.budget.init.update(
                ctx, account_id=value, new_budget=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.budget.budget.init.update account_id=value, new_budget=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="budgets",
        operation="update_budget",
        op_kwargs={"AccountId": account_id, "NewBudget": new_budget},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def select(
    hub,
    ctx,
    bucket: str,
    key: str,
    expression: str,
    expression_type: str,
    input_serialization: Dict,
    output_serialization: Dict,
    sse_customer_algorithm: str = None,
    sse_customer_key: str = None,
    sse_customer_key_md5: str = None,
    request_progress: Dict = None,
    scan_range: Dict = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This action filters the contents of an Amazon S3 object based on a simple structured query language (SQL) statement. In the request, along with the SQL expression, you must also specify a data serialization format (JSON, CSV, or Apache Parquet) of the object. Amazon S3 uses this format to parse object data into records, and returns only records that match the specified SQL expression. You must also specify the data serialization format for the response. This action is not supported by Amazon S3 on Outposts. For more information about Amazon S3 Select, see Selecting Content from Objects in the Amazon S3 User Guide. For more information about using SQL with Amazon S3 Select, see  SQL Reference for Amazon S3 Select and S3 Glacier Select in the Amazon S3 User Guide.   Permissions  You must have s3:GetObject permission for this operation. Amazon S3 Select does not support anonymous access. For more information about permissions, see Specifying Permissions in a Policy in the Amazon S3 User Guide.   Object Data Formats  You can use Amazon S3 Select to query objects that have the following format properties:    CSV, JSON, and Parquet - Objects must be in CSV, JSON, or Parquet format.    UTF-8 - UTF-8 is the only encoding type Amazon S3 Select supports.    GZIP or BZIP2 - CSV and JSON files can be compressed using GZIP or BZIP2. GZIP and BZIP2 are the only compression formats that Amazon S3 Select supports for CSV and JSON files. Amazon S3 Select supports columnar compression for Parquet using GZIP or Snappy. Amazon S3 Select does not support whole-object compression for Parquet objects.    Server-side encryption - Amazon S3 Select supports querying objects that are protected with server-side encryption. For objects that are encrypted with customer-provided encryption keys (SSE-C), you must use HTTPS, and you must use the headers that are documented in the GetObject. For more information about SSE-C, see Server-Side Encryption (Using Customer-Provided Encryption Keys) in the Amazon S3 User Guide. For objects that are encrypted with Amazon S3 managed encryption keys (SSE-S3) and customer master keys (CMKs) stored in AWS Key Management Service (SSE-KMS), server-side encryption is handled transparently, so you don't need to specify anything. For more information about server-side encryption, including SSE-S3 and SSE-KMS, see Protecting Data Using Server-Side Encryption in the Amazon S3 User Guide.    Working with the Response Body  Given the response size is unknown, Amazon S3 Select streams the response as a series of messages and includes a Transfer-Encoding header with chunked as its value in the response. For more information, see Appendix: SelectObjectContent Response .   GetObject Support  The SelectObjectContent action does not support the following GetObject functionality. For more information, see GetObject.    Range: Although you can specify a scan range for an Amazon S3 Select request (see SelectObjectContentRequest - ScanRange in the request parameters), you cannot specify the range of bytes of an object to return.    GLACIER, DEEP_ARCHIVE and REDUCED_REDUNDANCY storage classes: You cannot specify the GLACIER, DEEP_ARCHIVE, or REDUCED_REDUNDANCY storage classes. For more information, about storage classes see Storage Classes in the Amazon S3 User Guide.     Special Errors  For a list of special errors for this operation, see List of SELECT Object Content Error Codes   Related Resources     GetObject     GetBucketLifecycleConfiguration     PutBucketLifecycleConfiguration

    Args:
        bucket(str): The S3 bucket.
        key(str): The object key.
        sse_customer_algorithm(str, optional): The SSE Algorithm used to encrypt the object. For more information, see Server-Side Encryption (Using Customer-Provided Encryption Keys. . Defaults to None.
        sse_customer_key(str, optional): The SSE Customer Key. For more information, see Server-Side Encryption (Using Customer-Provided Encryption Keys. . Defaults to None.
        sse_customer_key_md5(str, optional): The SSE Customer Key MD5. For more information, see Server-Side Encryption (Using Customer-Provided Encryption Keys. . Defaults to None.
        expression(str): The expression that is used to query the object.
        expression_type(str): The type of the provided expression (for example, SQL).
        request_progress(Dict, optional): Specifies if periodic request progress information should be enabled. Defaults to None.
        input_serialization(Dict): Describes the format of the data in the object that is being queried.
        output_serialization(Dict): Describes the format of the data that you want Amazon S3 to return in response.
        scan_range(Dict, optional): Specifies the byte range of the object to get the records from. A record is processed when its first byte is contained by the range. This parameter is optional, but when specified, it must not be empty. See RFC 2616, Section 14.35.1 about how to specify the start and end of the range.  ScanRangemay be used in the following ways:    <scanrange><start>50</start><end>100</end></scanrange> - process only the records starting between the bytes 50 and 100 (inclusive, counting from zero)    <scanrange><start>50</start></scanrange> - process only the records starting after the byte 50    <scanrange><end>50</end></scanrange> - process only the records within the last 50 bytes of the file.  . Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.object_.content.select(
                ctx,
                bucket=value,
                key=value,
                expression=value,
                expression_type=value,
                input_serialization=value,
                output_serialization=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.object_.content.select bucket=value, key=value, expression=value, expression_type=value, input_serialization=value, output_serialization=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="select_object_content",
        op_kwargs={
            "Bucket": bucket,
            "Key": key,
            "SSECustomerAlgorithm": sse_customer_algorithm,
            "SSECustomerKey": sse_customer_key,
            "SSECustomerKeyMD5": sse_customer_key_md5,
            "Expression": expression,
            "ExpressionType": expression_type,
            "RequestProgress": request_progress,
            "InputSerialization": input_serialization,
            "OutputSerialization": output_serialization,
            "ScanRange": scan_range,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def upload(
    hub,
    ctx,
    account_id: str,
    vault_name: str,
    upload_id: str,
    checksum: str = None,
    range_: str = None,
    body: bytes = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation uploads a part of an archive. You can upload archive parts in any order. You can also upload them in parallel. You can upload up to 10,000 parts for a multipart upload. Amazon Glacier rejects your upload part request if any of the following conditions is true:    SHA256 tree hash does not matchTo ensure that part data is not corrupted in transmission, you compute a SHA256 tree hash of the part and include it in your request. Upon receiving the part data, Amazon S3 Glacier also computes a SHA256 tree hash. If these hash values don't match, the operation fails. For information about computing a SHA256 tree hash, see Computing Checksums.    Part size does not matchThe size of each part except the last must match the size specified in the corresponding InitiateMultipartUpload request. The size of the last part must be the same size as, or smaller than, the specified size.  If you upload a part whose size is smaller than the part size you specified in your initiate multipart upload request and that part is not the last part, then the upload part request will succeed. However, the subsequent Complete Multipart Upload request will fail.     Range does not alignThe byte range value in the request does not align with the part size specified in the corresponding initiate request. For example, if you specify a part size of 4194304 bytes (4 MB), then 0 to 4194303 bytes (4 MB - 1) and 4194304 (4 MB) to 8388607 (8 MB - 1) are valid part ranges. However, if you set a range value of 2 MB to 6 MB, the range does not align with the part size and the upload will fail.    This operation is idempotent. If you upload the same part multiple times, the data included in the most recent request overwrites the previously uploaded data. An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM).  For conceptual information and underlying REST API, see Uploading Large Archives in Parts (Multipart Upload) and Upload Part  in the Amazon Glacier Developer Guide.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID. .
        vault_name(str): The name of the vault.
        upload_id(str): The upload ID of the multipart upload.
        checksum(str, optional): The SHA256 tree hash of the data being uploaded. Defaults to None.
        range_(str, optional): Identifies the range of bytes in the assembled archive that will be uploaded in this part. Amazon S3 Glacier uses this information to assemble the archive in the proper sequence. The format of this header follows RFC 2616. An example header is Content-Range:bytes 0-4194303/*. Defaults to None.
        body(bytes, optional): The data to upload. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.multipart.part.upload(
                ctx, account_id=value, vault_name=value, upload_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.multipart.part.upload account_id=value, vault_name=value, upload_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="upload_multipart_part",
        op_kwargs={
            "accountId": account_id,
            "vaultName": vault_name,
            "uploadId": upload_id,
            "checksum": checksum,
            "range": range_,
            "body": body,
        },
    )
